/******************************************************************************/
/* Files to Include                                                           */
/******************************************************************************/

#if defined(__XC)
    #include <xc.h>         /* XC8 General Include File */
#elif defined(HI_TECH_C)
    #include <htc.h>        /* HiTech General Include File */
#endif

#include <stdint.h>        /* For uint8_t definition */
#include <stdbool.h>       /* For true/false definition */
//#include <stdio.h>

#include "system.h"        /* System funct/params, like osc/peripheral config */
#include "user.h"          /* User funct/params, such as InitApp */



/******************************************************************************/
/* User Global Variable Declaration                                           */
/******************************************************************************/

/* i.e. uint8_t <variable_name>; */

/******************************************************************************/
/* Main Program                                                               */
/******************************************************************************/

void putch(unsigned char c)
{
	i2clcdset(0x40,c);
	__delay_us(30);
}
void i2clcdclear()
{
	i2clcdset(0x00,0x01);
	__delay_ms(2);
	
}

void i2clcdlocate(unsigned char c)
{
	i2clcdset(0x00,(0x80 | c ));
}


void i2clcdinit()
{
		//LCD initialize
	__delay_ms(40);
	i2clcdset(0x00,0x38);
	i2clcdset(0x00,0x39);
	i2clcdset(0x00,0x14);
	i2clcdset(0x00,0x70);
	i2clcdset(0x00,0x56);
	i2clcdset(0x00,0x6C);
	__delay_ms(200);
	i2clcdset(0x00,0x38);
	i2clcdset(0x00,0x0C);
	i2clcdset(0x00,0x01);

	__delay_ms(2);
	i2clcdset(0x00,0x80);
}


unsigned char i2clcdset(unsigned char cmd,unsigned char data)
{
	unsigned char i,adr;
	//AQM0802 adress start
	LCD_SCL_HIGH;
	LCD_SDA_HIGH;
	__delay_us(2);
	LCD_SDA_LOW;	//start bit low
	__delay_us(1);
	LCD_SCL_LOW;
	__delay_us(2);
	//LCD address set

	i=7;
	adr = AQM0802ADR;
	do{
		if ( (adr & 0x80) ==0  ){
			LCD_SDA_LOW;
		}else{
			LCD_SDA_HIGH;
		}
		
		adr = adr << 1 ;
		LCD_SCL_HIGH;
		__delay_us(1);
		LCD_SCL_LOW;
		__delay_us(2);
	}while(i--);
	
	
	LCD_SDA_HIGH;	//ack (0) High imp
	__delay_us(2);
	LCD_SCL_HIGH;
	__delay_us(2);
	LCD_SCL_LOW;
	__delay_us(2);		
	
	//command
	i=7;
	do{
		if ( (cmd & 0x80) ==0  ){
			LCD_SDA_LOW;
		}else{
			LCD_SDA_HIGH;
		}
		
		cmd = cmd << 1 ;
		LCD_SCL_HIGH;
		__delay_us(1);
		LCD_SCL_LOW;
		__delay_us(2);
	}while(i--);
	
	
	LCD_SDA_HIGH;	//ack (0) High imp
	__delay_us(2);
	LCD_SCL_HIGH;
	__delay_us(2);
	LCD_SCL_LOW;
	__delay_us(2);		
	
	//data
	i=7;
	do{
		if ( (data & 0x80) ==0  ){
			LCD_SDA_LOW;
		}else{
			LCD_SDA_HIGH;
		}
		
		data = data << 1 ;
		LCD_SCL_HIGH;
		__delay_us(1);
		LCD_SCL_LOW;
		__delay_us(2);
	}while(i--);
	
	
	LCD_SDA_HIGH;	//ack (0) High imp
	__delay_us(2);
	LCD_SCL_HIGH;
	__delay_us(2);
	LCD_SCL_LOW;
	__delay_us(2);
	LCD_SDA_LOW;
	__delay_us(2);
	LCD_SCL_HIGH;
	__delay_us(2);	
	LCD_SCL_HIGH;
	__delay_us(2);	
	LCD_SDA_HIGH;	//stop bit	

	__delay_us(30);//usual wait time


}


void adinit(void){
	ANSEL = 0b00111000;//use AN3(2pin) and RC clock mode
	ADON=1;	//AD converter power is on
	ADFM=1;	//right justification
	VCFG=0;	//Vref =Vdd
	CHS1=0;	//
	CHS0=0;	//
}

unsigned int adconv(unsigned char adselect){
	unsigned int temp;
	ADCON0 = (ADCON0 & 0b11110011) |(( adselect <<2) & 0b00001100);//AD channel set 
	__delay_us(20);//20us wait
	GO_nDONE=1;	//convert start
	while(GO_nDONE);//now processing
	temp =ADRESH;
	temp =( temp<<8 )| ADRESL;
	return temp;
}



void main(void)
{
	unsigned int disp;	//voltage
    /* Configure the oscillator for the device */
    ConfigureOscillator();

    /* Initialize I/O and Peripherals for application */
    InitApp();
	i2clcdinit();
	i2clcdclear();
	adinit();
	
    while(1)
    {
		i2clcdlocate(0x00);
		disp = adconv(3);
		putch('A');
		putch('D');
		putch('C');
		putch('=');
		putch(((disp / 1000)%10)+0x30);//1000
		putch(((disp / 100)%10)+0x30);//100
		putch(((disp / 10)%10)+0x30);//10/		putch(((disp / 1)%10)+0x30);//1
		putch(((disp / 1)%10)+0x30);//1/				
		//DPH-102-M5 Panasonic Pressure Sensor 145.04 PSI (1000 kPa) Vented Gauge Male - M5 1 V ~ 5 V Module
		i2clcdlocate(0x40);
		if (disp<=310) disp = 0;
			else disp -= 310;	//310 as 1V @3.3V VDD
		disp = disp * 81;	//trim data
		putch('0');
		putch('.');
		putch(((disp / 10000)%10)+0x30);//1000		
		putch(((disp / 1000)%10)+0x30);//1000
		putch(((disp / 100)%10)+0x30);//100
//		putch(((disp / 10)%10)+0x30);//10/		putch(((disp / 1)%10)+0x30);//1
//		putch(((disp / 1)%10)+0x30);//1/				
		putch('M');
		putch('P');
		putch('a');
		


		
		//printf("V:%06d",disp);
		__delay_ms(10);
		
    }

}

